==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_entities/systemequipment_001/ManufacturerInfo.java <==

package net.datastream.schemas.mp_entities.systemequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERIALNUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MODEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MODELREVISION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}XCOORDINATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}YCOORDINATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ZCOORDINATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "manufacturercode",
    "serialnumber",
    "model",
    "modelrevision",
    "xcoordinate",
    "ycoordinate",
    "zcoordinate"
})
@XmlRootElement(name = "ManufacturerInfo")
public class ManufacturerInfo {

    @XmlElement(name = "MANUFACTURERCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturercode;
    @XmlElement(name = "SERIALNUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String serialnumber;
    @XmlElement(name = "MODEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String model;
    @XmlElement(name = "MODELREVISION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String modelrevision;
    @XmlElement(name = "XCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY xcoordinate;
    @XmlElement(name = "YCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY ycoordinate;
    @XmlElement(name = "ZCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY zcoordinate;

    /**
     * Obtient la valeur de la propriété manufacturercode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERCODE() {
        return manufacturercode;
    }

    /**
     * Définit la valeur de la propriété manufacturercode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERCODE(String value) {
        this.manufacturercode = value;
    }

    /**
     * Obtient la valeur de la propriété serialnumber.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSERIALNUMBER() {
        return serialnumber;
    }

    /**
     * Définit la valeur de la propriété serialnumber.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSERIALNUMBER(String value) {
        this.serialnumber = value;
    }

    /**
     * Obtient la valeur de la propriété model.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODEL() {
        return model;
    }

    /**
     * Définit la valeur de la propriété model.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODEL(String value) {
        this.model = value;
    }

    /**
     * Obtient la valeur de la propriété modelrevision.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODELREVISION() {
        return modelrevision;
    }

    /**
     * Définit la valeur de la propriété modelrevision.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODELREVISION(String value) {
        this.modelrevision = value;
    }

    /**
     * Obtient la valeur de la propriété xcoordinate.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getXCOORDINATE() {
        return xcoordinate;
    }

    /**
     * Définit la valeur de la propriété xcoordinate.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setXCOORDINATE(QUANTITY value) {
        this.xcoordinate = value;
    }

    /**
     * Obtient la valeur de la propriété ycoordinate.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getYCOORDINATE() {
        return ycoordinate;
    }

    /**
     * Définit la valeur de la propriété ycoordinate.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setYCOORDINATE(QUANTITY value) {
        this.ycoordinate = value;
    }

    /**
     * Obtient la valeur de la propriété zcoordinate.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getZCOORDINATE() {
        return zcoordinate;
    }

    /**
     * Définit la valeur de la propriété zcoordinate.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setZCOORDINATE(QUANTITY value) {
        this.zcoordinate = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/systemequipment_001/ManufacturerInfo.java <==

package net.datastream.schemas.mp_entities.systemequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERIALNUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MODEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MODELREVISION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}XCOORDINATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}YCOORDINATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ZCOORDINATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "manufacturercode",
    "serialnumber",
    "model",
    "modelrevision",
    "xcoordinate",
    "ycoordinate",
    "zcoordinate"
})
@XmlRootElement(name = "ManufacturerInfo")
public class ManufacturerInfo {

    @XmlElement(name = "MANUFACTURERCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturercode;
    @XmlElement(name = "SERIALNUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String serialnumber;
    @XmlElement(name = "MODEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String model;
    @XmlElement(name = "MODELREVISION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String modelrevision;
    @XmlElement(name = "XCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY xcoordinate;
    @XmlElement(name = "YCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY ycoordinate;
    @XmlElement(name = "ZCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY zcoordinate;

    /**
     * Gets the value of the manufacturercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERCODE() {
        return manufacturercode;
    }

    /**
     * Sets the value of the manufacturercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERCODE(String value) {
        this.manufacturercode = value;
    }

    /**
     * Gets the value of the serialnumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSERIALNUMBER() {
        return serialnumber;
    }

    /**
     * Sets the value of the serialnumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSERIALNUMBER(String value) {
        this.serialnumber = value;
    }

    /**
     * Gets the value of the model property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODEL() {
        return model;
    }

    /**
     * Sets the value of the model property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODEL(String value) {
        this.model = value;
    }

    /**
     * Gets the value of the modelrevision property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODELREVISION() {
        return modelrevision;
    }

    /**
     * Sets the value of the modelrevision property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODELREVISION(String value) {
        this.modelrevision = value;
    }

    /**
     * Gets the value of the xcoordinate property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getXCOORDINATE() {
        return xcoordinate;
    }

    /**
     * Sets the value of the xcoordinate property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setXCOORDINATE(QUANTITY value) {
        this.xcoordinate = value;
    }

    /**
     * Gets the value of the ycoordinate property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getYCOORDINATE() {
        return ycoordinate;
    }

    /**
     * Sets the value of the ycoordinate property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setYCOORDINATE(QUANTITY value) {
        this.ycoordinate = value;
    }

    /**
     * Gets the value of the zcoordinate property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getZCOORDINATE() {
        return zcoordinate;
    }

    /**
     * Sets the value of the zcoordinate property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setZCOORDINATE(QUANTITY value) {
        this.zcoordinate = value;
    }

}
